"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@collectable/core");
const node_1 = require("./node");
const functions_1 = require("../functions");
exports.DEFAULT_COMPARATOR = function (a, b) {
    return a < b ? -1 : a > b ? 1 : 0;
};
const REDBLACKTREE_TYPE = {
    type: Symbol('Collectable.RedBlackTree'),
    indexable: true,
    equals(other, tree) {
        return functions_1.isEqual(tree, other);
    },
    unwrap(tree) {
        return functions_1.unwrap(true, tree);
    },
    get(key, tree) {
        return functions_1.get(key, tree);
    },
    has(key, tree) {
        return functions_1.has(key, tree);
    },
    set(key, value, tree) {
        return functions_1.set(key, value, tree);
    },
    update(key, updater, tree) {
        return functions_1.update(updater, key, tree);
    },
    verifyKey(key, tree) {
        return core_1.isDefined(key);
    }
};
class RedBlackTreeImpl {
    constructor(_owner, _group, _compare, _root, _size) {
        this._owner = _owner;
        this._group = _group;
        this._compare = _compare;
        this._root = _root;
        this._size = _size;
        this['@@type'] = REDBLACKTREE_TYPE;
    }
    [Symbol.iterator]() {
        return functions_1.iterateFromFirst(this);
    }
}
exports.RedBlackTreeImpl = RedBlackTreeImpl;
function isRedBlackTree(arg) {
    return !!arg && arg['@@type'] === REDBLACKTREE_TYPE;
}
exports.isRedBlackTree = isRedBlackTree;
function createTree(mutable, comparator) {
    return new RedBlackTreeImpl(core_1.batch.owner(mutable), core_1.nextId(), comparator || exports.DEFAULT_COMPARATOR, node_1.NONE, 0);
}
exports.createTree = createTree;
function cloneTree(tree, group, mutable) {
    return new RedBlackTreeImpl(core_1.batch.owner(mutable), group, tree._compare, tree._root, tree._size);
}
exports.cloneTree = cloneTree;
function cloneAsMutable(tree) {
    return cloneTree(tree, core_1.nextId(), true);
}
exports.cloneAsMutable = cloneAsMutable;
function cloneAsImmutable(tree) {
    return cloneTree(tree, core_1.nextId(), false);
}
exports.cloneAsImmutable = cloneAsImmutable;
function doneMutating(tree) {
    if (tree._owner === -1) {
        tree._owner = 0;
    }
    return tree;
}
exports.doneMutating = doneMutating;

//# sourceMappingURL=red-black-tree.js.map
