import { isDefined } from '@collectable/core';
import { RedBlackTreeIterator, isNone, findPathToNodeByKey } from '../internals';
export function get(key, tree) {
    var node = tree._root, compare = tree._compare, found = false, value;
    do {
        if (isNone(node)) {
            found = true;
        }
        else {
            var c = compare(key, node.key);
            if (c === 0) {
                value = node.value;
                found = true;
            }
            else if (c > 0) {
                node = node._right;
            }
            else {
                node = node._left;
            }
        }
    } while (!found);
    return value;
}
/**
 * Determines whether or not a given key exists in the tree
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {K} key The key to look for
 * @param {RedBlackTree<K, V>} tree The input tree
 * @returns {boolean} True if the there is an entry for the specified key, otherwise false
 */
export function has(key, tree) {
    return isDefined(get(key, tree));
}
export function iterateFromKey(reverse, key, tree) {
    const path = findPathToNodeByKey(key, tree._root, tree._compare);
    return new RedBlackTreeIterator(path, reverse);
}

//# sourceMappingURL=get.js.map
