import { RedBlackTree } from '../internals';
/**
 * Returns an immutable version of the input tree.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTree<K, V>} tree The input tree
 * @returns {RedBlackTree<K, V>} An immutable copy of the input tree, or the same tree if already immutable
 */
export declare function freeze<K, V>(tree: RedBlackTree<K, V>): RedBlackTree<K, V>;
/**
 * Determines whether or not the tree is currently immutable.
 *
 * @export
 * @template K The type of keys in the tree
 * @template V The type of values in the tree
 * @param {RedBlackTree<K, V>} tree The input tree
 * @returns {boolean} True if the tree is currently immutable, otherwise false
 */
export declare function isFrozen<K, V>(tree: RedBlackTree<K, V>): boolean;
