export interface Node<K, V> {
    _group: number;
    key: K;
    value: V;
    _red: boolean;
    _left: Node<K, V>;
    _right: Node<K, V>;
    _count: number;
}
/** A read-only reference to an entry in a RedBlackTree instance. */
export declare type RedBlackTreeEntry<K, V> = {
    /** Read only. The hash key of this entry in the tree. */
    readonly key: K;
    /** Read only. The value of this entry in the tree. */
    readonly value: V;
};
export declare const enum BRANCH {
    NONE = 0,
    LEFT = 1,
    RIGHT = 2,
}
export declare const NONE: Node<any, any>;
export declare function createNode<K, V>(group: number, red: boolean, key: K, value: V): Node<K, V>;
export declare function cloneNode<K, V>(group: number, node: Node<K, V>): Node<K, V>;
export declare function isNone<K, V>(node: Node<K, V>): boolean;
export declare function editable<K, V>(group: number, node: Node<K, V>): Node<K, V>;
export declare function editRightChild<K, V>(group: number, node: Node<K, V>): Node<K, V>;
export declare function editLeftChild<K, V>(group: number, node: Node<K, V>): Node<K, V>;
export declare function assignValue<K, V>(value: V, node: Node<K, V>): boolean;
